from functools import wraps
from flask import request
from werkzeug.exceptions import Unauthorized

from flaschengeist import logger


def login_required(**kwargs):
    from .controller.accessTokenController import AccessTokenController
    ac_controller = AccessTokenController()
    permissions = None
    if "permissions" in kwargs:
        permissions = kwargs["roles"]

    def real_decorator(func):
        @wraps(func)
        def wrapper(*args, **kwargs):
            token = request.headers.get('Token')
            access_token = ac_controller.validate_token(token, request.user_agent, permissions)
            if access_token:
                kwargs['access_token'] = access_token
                logger.debug("token {{ {} }} is valid".format(token))
                return func(*args, **kwargs)
            else:
                logger.info("token {{ {} }} is not valid".format(token))
                raise Unauthorized
        return wrapper
    return real_decorator
